@@ -1,10 +1,10 @@
 import pytest
 import os
 
-from criteo_api_retailmedia_preview.configuration import Configuration
-from criteo_api_retailmedia_preview.api.gateway_api import GatewayApi
-from criteo_api_retailmedia_preview.api_client import ApiClient
-from criteo_api_retailmedia_preview.rest import ApiException
+from criteo_api_retailmedia_v2022_04.configuration import Configuration
+from criteo_api_retailmedia_v2022_04.api.gateway_api import GatewayApi
+from criteo_api_retailmedia_v2022_04.api_client import ApiClient
+from criteo_api_retailmedia_v2022_04.rest import ApiException
 
 class TestGatewayApi:
   @pytest.fixture(autouse=True)
